# Automatically generated by TopicTreeSpecPrinter(**kwargs).
# The kwargs were:
# - fileObj: file
# - width: 70
# - treeDoc: None
# - indentStep: 4
# - footer: '# End of topic tree definition. Note that application may l...'


class topic_1:
    """
    Explain when topic_1 should be used
    """

    class subtopic_11:
        """
        Explain when subtopic_11 should be used
        """

class topic_2:
    """
    Some something useful about topic2
    """

    class subtopic_21:
        """
        description for subtopic 21
        """


# End of topic tree definition. Note that application may load
# more than one definitions provider.



"""
Aggregates policies for pubsub. Mainly, related to messaging protocol.

:copyright: Copyright since 2006 by Oliver Schoenborn, all rights reserved.
:license: BSD, see LICENSE_BSD_Simple.txt for details.
"""

msgProtocolTransStage = None

msgDataProtocol    = 'kwargs'
msgDataArgName     = None
senderKwargNameAny = False


def setMsgDataArgName(stage, listenerArgName, senderArgNameAny=False):
    global senderKwargNameAny
    global msgDataArgName
    global msgProtocolTransStage
    senderKwargNameAny = senderArgNameAny
    msgDataArgName = listenerArgName
    msgProtocolTransStage = stage
    #print('%s' % repr(policies.msgProtocolTransStage))
    #print('%s' % repr(policies.msgDataProtocol))
    #print('%s' % repr(policies.senderKwargNameAny))
    #print('%s' % repr(policies.msgDataArgName))
    #print('override "arg1" protocol arg name: %s' % argName)



"""

:copyright: Copyright since 2006 by Oliver Schoenborn, all rights reserved.
:license: BSD, see LICENSE.txt for details.

"""

from pubsub import pub
from pubsub.py2and3 import print_
from pubsub.utils.notification import useNotifyByWriteFile, IgnoreNotificationsMixin


# create one special notification handler that ignores all except
# one type of notification
class MyPubsubNotifHandler(IgnoreNotificationsMixin):

    def notifySubscribe(self, pubListener, topicObj, newSub):
        newSubMsg = ''
        if not newSub:
            newSubMsg = ' was already'
        msg = 'MyPubsubNotifHandler: listener %s%s subscribed to %s'
        print_(msg % (pubListener.name(), newSubMsg, topicObj.getName()))


pub.addNotificationHandler( MyPubsubNotifHandler() )


# print_(all notifications to stdout)
import sys
useNotifyByWriteFile(sys.stdout, prefix='NotifyByWriteFile:')



# -*- coding: utf-8 -*-
#---------------------------------------------------------------------------
# This file is generated by wxPython's PI generator.  Do not edit by hand.
#
# The *.pyi files are used by PyCharm and other development tools to provide
# more information, such as PEP 484 type hints, than it is able to glean from
# introspection of extension types and methods.  They are not intended to be
# imported, executed or used for any other purpose other than providing info
# to the tools. If you don't use use a tool that makes use of .pyi files then
# you can safely ignore this file.
#
# See: https://www.python.org/dev/peps/pep-0484/
#      https://www.jetbrains.com/help/pycharm/2016.1/type-hinting-in-pycharm.html
#
# Copyright: (c) 2017 by Total Control Software
# License:   wxWindows License
#---------------------------------------------------------------------------


"""
This module contains a few classes that are only available on Windows.
"""
#-- begin-_msw --#

import wx
#-- end-_msw --#
#-- begin-metafile --#

class Metafile(wx.Object):
    """
    Metafile(filename=wx.EmptyString)
    
    A wxMetafile represents the MS Windows metafile object, so metafile
    operations have no effect in X.
    """

    def __init__(self, filename=wx.EmptyString):
        """
        Metafile(filename=wx.EmptyString)
        
        A wxMetafile represents the MS Windows metafile object, so metafile
        operations have no effect in X.
        """

    def IsOk(self):
        """
        IsOk() -> bool
        
        Returns true if the metafile is valid.
        """

    def Play(self, dc):
        """
        Play(dc) -> bool
        
        Plays the metafile into the given device context, returning true if
        successful.
        """

    def SetClipboard(self, width=0, height=0):
        """
        SetClipboard(width=0, height=0) -> bool
        
        Passes the metafile data to the clipboard.
        """
# end of class Metafile


class MetafileDC(wx.DC):
    """
    MetafileDC(filename=wx.EmptyString)
    
    This is a type of device context that allows a metafile object to be
    created (Windows only), and has most of the characteristics of a
    normal wxDC.
    """

    def __init__(self, filename=wx.EmptyString):
        """
        MetafileDC(filename=wx.EmptyString)
        
        This is a type of device context that allows a metafile object to be
        created (Windows only), and has most of the characteristics of a
        normal wxDC.
        """

    def Close(self):
        """
        Close() -> Metafile
        
        This must be called after the device context is finished with.
        """
# end of class MetafileDC

#-- end-metafile --#
#-- begin-axbase --#

class PyAxBaseWindow(wx.Window):
    """
    PyAxBaseWindow(parent, id=-1, pos=wx.DefaultPosition, size=wx.DefaultSize, style=0, name=wx.PanelNameStr)
    PyAxBaseWindow()
    
    A Window class for use with ActiveX controls.
    
    This Window class exposes some low-level Microsoft Windows
    specific methods which can be overridden in Python.  Intended for
    use as an ActiveX container, but could also be useful
    elsewhere.
    """

    def __init__(self, *args, **kw):
        """
        PyAxBaseWindow(parent, id=-1, pos=wx.DefaultPosition, size=wx.DefaultSize, style=0, name=wx.PanelNameStr)
        PyAxBaseWindow()
        
        A Window class for use with ActiveX controls.
        
        This Window class exposes some low-level Microsoft Windows
        specific methods which can be overridden in Python.  Intended for
        use as an ActiveX container, but could also be useful
        elsewhere.
        """

    def MSWTranslateMessage(self, msg):
        """
        MSWTranslateMessage(msg) -> bool
        """
# end of class PyAxBaseWindow

#-- end-axbase --#



"""
Adapted from wxPython website at http://wiki.wxpython.org/ModelViewController/.

:copyright: Copyright since 2006 by Oliver Schoenborn, all rights reserved.
:license: BSD, see LICENSE.txt for details.
"""

import wx

from pubsub import pub
from pubsub.py2and3 import print_

print_('pubsub API version', pub.VERSION_API)

# notification
from pubsub.utils.notification import useNotifyByWriteFile
import sys
useNotifyByWriteFile(sys.stdout)

# the following two modules don't know about each other yet will
# exchange data via pubsub:
from wx_win1 import View
from wx_win2 import ChangerWidget


class Model:

  def __init__(self):
    self.myMoney = 0

  def addMoney(self, value):
    self.myMoney += value
    #now tell anyone who cares that the value has been changed
    pub.sendMessage("money_changed", money=self.myMoney)

  def removeMoney(self, value):
    self.myMoney -= value
    #now tell anyone who cares that the value has been changed
    pub.sendMessage("money_changed", money=self.myMoney)


class Controller:

  def __init__(self):
    self.model = Model()

    #set up the first frame which displays the current Model value
    self.view1 = View()
    self.view1.setMoney(self.model.myMoney)

    #set up the second frame which allows the user to modify the Model's value
    self.view2 = ChangerWidget()

    self.view1.Show()
    self.view2.Show()

    pub.subscribe(self.changeMoney, 'money_changing')

  def changeMoney(self, amount):
    if amount >= 0:
        self.model.addMoney(amount)
    else:
        self.model.removeMoney(-amount)


if __name__ == "__main__":
    app = wx.App()
    c = Controller()
    sys.stdout = sys.__stdout__

    print_('---- Starting main event loop ----')
    app.MainLoop()
    print_('---- Exited main event loop ----')
